@@ -14,6 +14,7 @@
 # pip install {opts} {packages}
 
 ZUUL_CLONER=/usr/zuul-env/bin/zuul-cloner
+BRANCH_NAME=stable/liberty
 neutron_installed=$(echo "import neutron" | python 2>/dev/null ; echo $?)
 
 set -e
@@ -28,6 +29,7 @@ elif [ -x "$ZUUL_CLONER" ]; then
     cd /tmp
     $ZUUL_CLONER --cache-dir \
         /opt/git \
+        --branch $BRANCH_NAME \
         git://git.openstack.org \
         openstack/neutron
     cd openstack/neutron
@@ -35,7 +37,7 @@ elif [ -x "$ZUUL_CLONER" ]; then
     cd "$cwd"
 else
     echo "PIP HARDCODE" > /tmp/tox_install.txt
-    pip install -U -egit+https://git.openstack.org/openstack/neutron@stable/liberty#egg=neutron
+    pip install -U -egit+https://git.openstack.org/openstack/neutron@$BRANCH_NAME#egg=neutron
 fi
 
 pip install -U $*
